Index: trunk/MagicSoft/Mars/mfileio/MCT1ReadPreProc.h
===================================================================
--- trunk/MagicSoft/Mars/mfileio/MCT1ReadPreProc.h	(revision 4183)
+++ trunk/MagicSoft/Mars/mfileio/MCT1ReadPreProc.h	(revision 4457)
@@ -22,5 +22,5 @@
 class MCerPhotEvt;
 class MPedPhotCam;
-class MBlindPixels;
+class MBadPixelsCam;
 class MRawRunHeader;
 class MTaskList;
@@ -45,5 +45,5 @@
     MMcTrig       *fMcTrig;  // mc data container for trigger information
     MSrcPosCam    *fSrcPos;  // source position in the camera
-    MBlindPixels  *fBlinds;  // Array holding blind pixels
+    MBadPixelsCam *fBlinds;  // Array holding blind pixels
     MRawRunHeader *fRawRunHeader; // raw run header
     MParList      *fParList;      // parameter list

Index: trunk/MagicSoft/Mars/mfileio/MCT1ReadPreProc.cc
===================================================================
--- trunk/MagicSoft/Mars/mfileio/MCT1ReadPreProc.cc	(revision 4183)
+++ trunk/MagicSoft/Mars/mfileio/MCT1ReadPreProc.cc	(revision 4457)
@@ -18,5 +18,5 @@
 !   Author(s): Thomas Bretz, 11/2002 <mailto:tbretz@astro.uni-wuerzburg.de>
 !
-!   Copyright: MAGIC Software Development, 2000-2003
+!   Copyright: MAGIC Software Development, 2000-2004
 !
 !
@@ -42,5 +42,5 @@
 //    MMcTrig         mc data container for trigger information
 //    MSrcPosCam      source position in the camera
 //    MBlindPixels    Array holding blind pixels
 //
 /////////////////////////////////////////////////////////////////////////////
@@ -74,5 +74,6 @@
 #include "MGeomCam.h"
 #include "MSrcPosCam.h"
-#include "MBlindPixels.h"
+#include "MBadPixelsCam.h"
+#include "MBadPixelsPix.h"
 
 #include "MRawRunHeader.h"
@@ -245,5 +246,5 @@
         {
             *fLog << i << " ";
-            fBlinds->SetPixelBlind(i);
+            (*fBlinds)[i].SetUnsuitable(MBadPixelsPix::kUnreliableRun);
         }
     *fLog << endl;
@@ -255,5 +256,5 @@
         {
             *fLog << i << " ";
-            fBlinds->SetPixelBlind(i);
+            (*fBlinds)[i].SetUnsuitable(MBadPixelsPix::kUnreliableRun);
         }
     *fLog << endl;
@@ -262,5 +263,5 @@
     fBlnd.Set(iMAXNUMPIX);
     for (int i=0; i<iMAXNUMPIX; i++)
-        fBlnd[i] = fBlinds->IsBlind(i) ? 1 : 0;
+        fBlnd[i] = (*fBlinds)[i].IsBad() ? 1 : 0;
 
     fBlinds->SetReadyToSave();
@@ -349,5 +350,5 @@
 
     // float   frms_pedsig_phot[iMAXNUMPIX];      // standard deviation of the calibrated signals from the pedestal run */
-    fPedest->InitSize(iMAXNUMPIX);
+    fPedest->Init(*fGeom);
 
     fPedRMS.Set(iMAXNUMPIX);
@@ -775,5 +776,5 @@
     //  look for the pedestal class in the plist
     //
-    fBlinds = (MBlindPixels*)pList->FindCreateObj("MBlindPixels");
+    fBlinds = (MBadPixelsCam*)pList->FindCreateObj("MBadPixelsCam");
     if (!fBlinds)
         return kFALSE;
@@ -818,5 +819,5 @@
     Rewind();
 
-    fPedest->InitSize(iMAXNUMPIX);
+    fPedest->Init(*fGeom);
 
     return GetSelector() ? GetSelector()->CallPreProcess(pList) : kTRUE;
@@ -901,8 +902,6 @@
     fBlinds->Clear();
     for (int i=0; i<iMAXNUMPIX; i++)
-        if ( fBlnd[i]==1 )
-        {
-            fBlinds->SetPixelBlind(i);
-        }
+        if (fBlnd[i]==1)
+            (*fBlinds)[i].SetUnsuitable(MBadPixelsPix::kUnreliableRun);
 
     // reset pedestal RMS for this event
@@ -42,5 +42,5 @@
 //    MMcTrig         mc data container for trigger information
 //    MSrcPosCam      source position in the camera
-//    MBlindPixels    Array holding blind pixels
+//    MBadPixelsCam   Array holding blind pixels
 //
 /////////////////////////////////////////////////////////////////////////////